@@ -19,8 +19,8 @@
  */
 
 var pageMod = require("page-mod");
-var tabs = require("tabs");
-var data = require("self").data;
+var tabs = require("sdk/tabs");
+var data = require("sdk/self").data;
 
 exports.testDetectEmailAddressFound = function (test) {
     test.waitUntilDone();
